@@ -2,17 +2,21 @@
     kleo/debug.h
 
     This file is part of libkleopatra, the KDE keymanagement library
-    SPDX-FileCopyrightText: 2021 g10 Code GmbH
+    SPDX-FileCopyrightText: 2021, 2022 g10 Code GmbH
     SPDX-FileContributor: Ingo Klöcker <dev@ingo-kloecker.de>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef LIBKLEO_DEBUG_H
-#define LIBKLEO_DEBUG_H
+#pragma once
 
 #include "kleo_export.h"
 
+namespace GpgME
+{
+class Key;
+}
+
 namespace Kleo
 {
 class KeyGroup;
@@ -20,6 +24,6 @@ class KeyGroup;
 
 class QDebug;
 
-KLEO_EXPORT QDebug operator<<(QDebug debug, const Kleo::KeyGroup &group);
+KLEO_EXPORT QDebug operator<<(QDebug debug, const GpgME::Key &key);
 
-#endif // LIBKLEO_DEBUG_H
+KLEO_EXPORT QDebug operator<<(QDebug debug, const Kleo::KeyGroup &group);
